def _get_or_create_runner_request_info() -> dict:
    return {
        'endpoint': f"job/runner/deployment"
    }
